@@ -12,13 +12,13 @@
 namespace hyperflux {
 
 struct FreeEnergySamplingSettings : public samply::Settings {
-
     FreeEnergySamplingSettings() = default;
     FreeEnergySamplingSettings(const FreeEnergySamplingSettings&) = default;
 
     FreeEnergySamplingSettings(const samply::Settings base_settings)
-        : samply::Settings(base_settings) {}
-
+        : samply::Settings(base_settings)
+    {
+    }
 
     // Numerics and performance settings.
     double truncation_multiplier = 1.0;
