@@ -1,8 +1,6 @@
 """Definition of the prior distribution of metabolite concentrations.
 """
 
-from __future__ import annotations
-
 import csv
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
@@ -21,7 +19,7 @@ from .metabolite import Metabolite
 from .utils import get_path
 
 
-class ConcentrationsPrior(object):
+class ConcentrationsPrior:
     """
     Manages prior distributions of concentrations for specific metabolites or
     compartments. This class provides a distribution for the concentration of any
@@ -70,7 +68,7 @@ class ConcentrationsPrior(object):
     def load(
         prior_file: Union[Path, str],
         compound_cache: Optional[CompoundCache] = None,
-    ) -> ConcentrationsPrior:
+    ) -> "ConcentrationsPrior":
         """Loads the concentration priors from a .csv file.
 
         Parameters
@@ -151,7 +149,7 @@ class ConcentrationsPrior(object):
 
     def add(
         self,
-        other: ConcentrationsPrior,
+        other: "ConcentrationsPrior",
         overwrite_metabolite_priors: bool = True,
         overwrite_compartment_priors: bool = True,
         overwrite_default_prior: bool = True,
