@@ -27,7 +27,7 @@ from .utils import get_internal_cycles, tighten_model_bounds
 logger = logging.getLogger(__name__)
 
 
-class StructuralAssessment(object):
+class StructuralAssessment:
     """This class is used to find thermodynamic inconsistencies in the definition of the
     network that make the model infeasible. Inconsistencies arise when flux constraints
     (steady state and irreversibilities) prevent any thermodynamically feasible non-zero
@@ -249,7 +249,7 @@ class StructuralAssessment(object):
         return True
 
 
-class QuantitativeAssessment(object):
+class QuantitativeAssessment:
     """Quantitative thermodynamic assessment of a metabolic network. This process
     combines thermodynamic data and flux constraints to identify parts of the network
     where the mechanism in the model is possibly incorrect.
