@@ -2,8 +2,6 @@
 problems.
 """
 
-from __future__ import annotations
-
 import logging
 import multiprocessing
 import os
@@ -23,7 +21,7 @@ from .flux_space import FluxSpace
 from .thermodynamic_space import ThermodynamicSpace, ThermodynamicSpaceBasis
 
 logger = logging.getLogger(__name__)
-_pmo_problem: PmoProblem
+_pmo_problem: "PmoProblem"
 
 
 class PmoProblemPool:
@@ -63,7 +61,7 @@ class PmoProblemPool:
         )
 
     def map(
-        self, fn: Callable[[PmoProblem, Any], Any], inputs: Iterable[Any]
+        self, fn: Callable[["PmoProblem", Any], Any], inputs: Iterable[Any]
     ) -> List[Any]:
         """Executes a function on each input element. This is the same as the regular
         :code:`map` function, except that it executes in parallel on the available
@@ -98,12 +96,12 @@ class PmoProblemPool:
         _pmo_problem = PmoProblem(*argv)
 
     @staticmethod
-    def _pool_task(v: Tuple[Callable[[PmoProblem, Any], Any], Any]):
+    def _pool_task(v: Tuple[Callable[["PmoProblem", Any], Any], Any]):
         global _pmo_problem
         return v[0](_pmo_problem, v[1])
 
 
-class PmoProblem(object):
+class PmoProblem:
     """Construction and solution of a Probabilistic Metabolic Optimization (PMO)
     problem.
 
@@ -142,7 +140,7 @@ class PmoProblem(object):
         network: Union[cobra.Model, FluxSpace],
         thermodynamic_space: ThermodynamicSpace,
         thermodynamic_space_basis: ThermodynamicSpaceBasis = None,
-        objective: Callable[[PmoProblem], cp.problems.objective.Objective] = None,
+        objective: Callable[["PmoProblem"], cp.problems.objective.Objective] = None,
         confidence_level: float = default_confidence_level,
         min_drg: float = default_min_drg,
         max_drg: float = default_max_drg,
@@ -235,12 +233,12 @@ class PmoProblem(object):
     @property
     def objective(
         self,
-    ) -> Optional[Callable[[PmoProblem], cp.problems.objective.Objective]]:
+    ) -> Optional[Callable[["PmoProblem"], cp.problems.objective.Objective]]:
         """Gets the function that constructs the PMO objective."""
         return self._objective
 
     @objective.setter
-    def objective(self, value: Callable[[PmoProblem], cp.problems.objective.Objective]):
+    def objective(self, value: Callable[["PmoProblem"], cp.problems.objective.Objective]):
         """Sets the function that constructs the PMO objective."""
         self._objective = value
         self._rebuild_cvxpy_problem()
@@ -372,7 +370,7 @@ class PmoProblem(object):
         self._problem.solve(solver=self.solver, verbose=verbose, **options)
         return self._problem.status
 
-    def rebuild_for_directions(self, directions: np.array) -> PmoProblem:
+    def rebuild_for_directions(self, directions: np.array) -> "PmoProblem":
         """Construct a copy of this PMO problem constrained to the given reaction
         directions.
 
