@@ -44,7 +44,7 @@ logger = logging.getLogger(__name__)
 _us_model: cobra.Model
 
 
-class TFSModel(object):
+class TFSModel:
     """Object holding the information necessary to run TFS.
 
     Parameters
