@@ -1,6 +1,5 @@
 """Description of the space of thermodynamics-related quantities of a metabolic network.
 """
-from __future__ import annotations
 
 import logging
 from typing import Dict, List, Optional, Tuple, Union
@@ -35,7 +34,7 @@ from .utils import (
 logger = logging.getLogger(__name__)
 
 
-class ThermodynamicSpace(object):
+class ThermodynamicSpace:
     """
     Construction, description and manipulation of the thermodynamic space of
     a metabolic network.
@@ -200,7 +199,7 @@ class ThermodynamicSpace(object):
         estimator: GibbsEstimatorInterface = None,
         parameters: CompartmentParameters = None,
         concentrations: ConcentrationsPrior = None,
-    ) -> ThermodynamicSpace:
+    ) -> "ThermodynamicSpace":
         """Constructs a thermodynamic space from a cobrapy model.
 
         Parameters
@@ -295,7 +294,7 @@ class ThermodynamicSpace(object):
         return log_conc_mean, log_conc_cov
 
 
-class ThermodynamicSpaceBasis(object):
+class ThermodynamicSpaceBasis:
     """
     Full-dimensional basis of the thermodynamic space. It is possible to make only
     selected variables explicit in the basis, reducing its dimensionality.
@@ -319,7 +318,7 @@ class ThermodynamicSpaceBasis(object):
 
     def __init__(
         self,
-        thermodynamic_space: ThermodynamicSpace,
+        thermodynamic_space: "ThermodynamicSpace",
         explicit_log_conc: bool = True,
         explicit_drg0: bool = True,
         explicit_drg: bool = True,
@@ -444,7 +443,7 @@ class ThermodynamicSpaceBasis(object):
 
     def _compute_basis(
         self,
-        thermodynamic_space: ThermodynamicSpace,
+        thermodynamic_space: "ThermodynamicSpace",
         explicit_log_conc,
         explicit_drg0,
         explicit_drg,
